@@ -2,12 +2,12 @@ from quickbuild.adapters.aio import AsyncQBClient
 from quickbuild.adapters.sync import QBClient
 from quickbuild.exceptions import (
     QBError,
-    QBForbidden,
+    QBForbiddenError,
     QBNotFoundError,
     QBProcessingError,
 )
 
-__version__ = '0.3.0'
+__version__ = '0.4.1'
 
 __all__ = (
     # adapters
@@ -15,7 +15,7 @@ __all__ = (
     'QBClient',
     # exceptions
     'QBError',
-    'QBForbidden',
+    'QBForbiddenError',
     'QBNotFoundError',
     'QBProcessingError',
 )
