@@ -26,7 +26,7 @@ def test_sync_client():
             timeout=10,
         )
 
-        version = client.get_version()
+        version = client.system.get_version()
         assert version.major == 6
         assert version.minor == 0
         assert version.patch == 9
@@ -65,11 +65,12 @@ async def test_async_client(aiohttp_mock):
 
         aiohttp_mock.get(
             'http://server/rest/version',
+            content_type='text/plain',
             body=GET_VERSION_DATA,
             status=200,
         )
 
-        version = await client.get_version()
+        version = await client.system.get_version()
         assert version.major == 6
         assert version.minor == 0
         assert version.patch == 9
@@ -91,17 +92,19 @@ async def test_async_client_retry(aiohttp_mock):
 
     aiohttp_mock.get(
         'http://server/rest/version',
+        content_type='text/plain',
         body='Server error',
         status=500,
     )
 
     aiohttp_mock.get(
         'http://server/rest/version',
+        content_type='text/plain',
         body=GET_VERSION_DATA,
         status=200,
     )
 
-    version = await client.get_version()
+    version = await client.system.get_version()
     assert version.major == 6
     assert version.minor == 0
     assert version.patch == 9
@@ -131,6 +134,6 @@ async def test_async_client_retry_exception(aiohttp_mock):
     )
 
     with pytest.raises(QBError):
-        await client.get_version()
+        await client.system.get_version()
 
     await client.close()
